/* NOTE:
 * 2810: To save cookies: Ctrl+I > Permissions > Cookies > Allow
 * Manage site exceptions: about:preferences#privacy
 *    > Cookies and Site Data > Manage Exceptions
 *    > Permissions > Settings
 ***/


/* Soften some settings ***/
// Override recipes: https://github.com/arkenfox/user.js/issues/1080
/* Disable RFP -> Add-on "CanvasBlocker": Only enable for "canvas" and "audio" APIs */
user_pref("privacy.resistFingerprinting", false); // 4501
user_pref("privacy.resistFingerprinting.letterboxing", false); // 4504: Pointless if not using RFP
/* Enable web conferencing */
user_pref("webgl.disabled", false); // 4520: Mostly pointless if not using RFP
/* "Always" send a cross-origin referer -> Add-on "Smart Referer": Enable "Strict mode" & add exceptions */
user_pref("network.http.referer.XOriginPolicy", 0); // 1601
/* When a CA cannot be reached to validate a OCSP cert, don't terminate the connection */
user_pref("security.OCSP.require", false); // 1212 TMP
/* OPT: Enable DRM ***/
//user_pref("media.eme.enabled", true); // 2022
////user_pref("media.gmp-widevinecdm.enabled", true); // 2021 default-inactive in user.js
/* OPT: Enable session restore ***/
//user_pref("browser.startup.page", 3); // 0102: startup page = resume previous session
//user_pref("browser.sessionstore.privacy_level", 0); // 1003: to restore cookies/formdata if not sanitized
//user_pref("privacy.clearOnShutdown.history", false); // 2811
////user_pref("privacy.cpd.history", false); // 2812: to match when you use Ctrl+Shift+Del


/* Locale (esp. for offline translations) ***/
user_pref("intl.accept_languages", "en-us, en, de-de, de"); // 0210: preferred languages for displaying pages


/* Location bar search ***/
// NOTE: Live search suggestions is disabled. If no match was found for a bookmark in the address bar search, the search engine is then used.
// Press Ctrl+K to only use the search engine.
user_pref("keyword.enabled", true); // 0801: Enable location bar search
// 5010: Disable location bar suggestion types
user_pref("browser.urlbar.suggest.history", false);
user_pref("browser.urlbar.suggest.openpage", false);
user_pref("browser.urlbar.suggest.topsites", false);


/* Misc ***/
user_pref("browser.safebrowsing.malware.enabled", false); // 0401: Disable SB (Safe Browsing) -> Add-on "uBlock Origin"
user_pref("browser.safebrowsing.phishing.enabled", false); // 0401: Disable SB (Safe Browsing) -> Add-on "uBlock Origin"
user_pref("signon.rememberSignons", false); // 5003: Disable saving passwords -> Add-on "KeePassXC"
user_pref("browser.download.forbid_open_with", true); // 5009: Disable "Open with" in download dialog -> firejail
// 2812: Ctrl+Shift+Del: Only not clear siteSettings
user_pref("privacy.cpd.offlineApps", true);
user_pref("privacy.cpd.cookies", true);


/*** [SECTION 9000]: NON-PROJECT RELATED ***/
/* WELCOME & WHAT'S NEW NOTICES ***/
user_pref("startup.homepage_welcome_url", ""); // "Blank Page" instead of "Firefox Home"
user_pref("startup.homepage_welcome_url.additional", "");
user_pref("startup.homepage_override_url", ""); // What's New page after updates
/* WARNINGS ***/
user_pref("browser.tabs.warnOnClose", true); // Alt+F4
user_pref("browser.tabs.warnOnCloseOtherTabs", true);
user_pref("browser.tabs.warnOnOpen", false);
user_pref("full-screen-api.warning.delay", 0);
user_pref("full-screen-api.warning.timeout", 0);
/* UPDATES ***/
user_pref("app.update.auto", false); // [NON-WINDOWS] Disable auto app updates
/* APPEARANCE ***/
user_pref("browser.download.autohideButton", false);
user_pref("toolkit.legacyUserProfileCustomizations.stylesheets", true); // Allow userChrome/userContent
user_pref("ui.prefersReducedMotion", 1); // Disable chrome animations  [RESTART] [HIDDEN PREF]
user_pref("ui.systemUsesDarkTheme", 1); // 0=light, 1=dark: with RFP this only affects chrome [HIDDEN PREF]
/* CONTENT BEHAVIOR ***/
user_pref("accessibility.typeaheadfind", true); // Enable "Find As You Type"
user_pref("clipboard.autocopy", false); // Disable autocopy default [LINUX]
user_pref("layout.spellcheckDefault", 2); // 0=none, 1-multi-line, 2=multi-line & single-line
/* FIREFOX HOME CONTENT ***/
user_pref("browser.newtabpage.activity-stream.feeds.section.topstories", false); // Recommended by Pocket
user_pref("browser.newtabpage.activity-stream.section.highlights.includePocket", false);
/* UX BEHAVIOR ***/
user_pref("browser.backspace_action", 0); // 0=previous page, 1=scroll up, 2=do nothing
user_pref("browser.shell.checkDefaultBrowser", false); // Disable default browser check on startup
user_pref("browser.urlbar.decodeURLsOnCopy", true); // See bugzilla 1320061 [FF53+]
user_pref("general.autoScroll", true); // Middle-click enabling auto-scrolling [DEFAULT: false on Linux]
/* UX FEATURES ***/
user_pref("extensions.pocket.enabled", false); // Pocket Account [FF46+]
user_pref("extensions.screenshots.disabled", true);
user_pref("identity.fxaccounts.enabled", false); // Firefox Accounts & Sync [FF60+] [RESTART]
user_pref("reader.parse-on-load.enabled", false); // Reader View
/* OTHER ***/
user_pref("browser.bookmarks.max_backups", 2);
user_pref("network.manage-offline-status", false); // See bugzilla 620472
//user_pref("xpinstall.signatures.required", false); // Enforced extension signing (Nightly/ESR)


/*** MY PREFS ***/
/* UX BEHAVIOR ***/
user_pref("findbar.highlightAll", true);
user_pref("general.smoothScroll", false);
user_pref("browser.download.start_downloads_in_tmp_dir", true); // instead of the download dir [FF102+]
/* APPEARANCE ***/
user_pref("browser.uidensity", 1); // Density: Compact
user_pref("browser.tabs.inTitlebar", 1); // Replace the title bar with the tab bar [LINUX]
user_pref("browser.toolbars.bookmarks.visibility", "always"); // Bookmarks Toolbar > Always Show
user_pref("browser.tabs.firefox-view", false); // [FF106+]
user_pref("browser.tabs.tabmanager.enabled", false); // Disable icon "v List all tabs" [FF106+]
/* HW & SW specific ***/
//user_pref("layout.frame_rate", 144); // Set display frame rate [Hz] if not auto-detected
// KDE integration [LINUX]
//user_pref("widget.use-xdg-desktop-portal.mime-handler", 1); // KDE file selection and print dialogs
//user_pref("widget.use-xdg-desktop-portal.file-picker", 1);
user_pref("media.hardwaremediakeys.enabled", false); // Prevents duplicate entries in the Media Player widget or tray icon
